==> igniteui-webcomponents-core-3.2.2.tgz: package/esm5/lib/MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { MovingAverageConvergenceDivergenceIndicatorDescription } from "./MovingAverageConvergenceDivergenceIndicatorDescription";
/**
 * @hidden
 */
var MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata, _super);
    function MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.b = function (a) {
        if (MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.a == null) {
            MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.c(MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.a);
        }
        if (a.g(MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.s(MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.a);
    };
    MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.c = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.c(a);
        a.item("ShortPeriod", "Number:int");
        a.item("LongPeriod", "Number:int");
        a.item("SignalPeriod", "Number:int");
    };
    MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.d = function (a) {
        MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.b(a);
        a.u("MovingAverageConvergenceDivergenceIndicator", function () { return new MovingAverageConvergenceDivergenceIndicatorDescription(); });
        a.t("MovingAverageConvergenceDivergenceIndicator", MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.a);
    };
    MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.$t = markType(MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata, 'MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata');
    MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.a = null;
    return MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata;
}(Base));
export { MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { MovingAverageConvergenceDivergenceIndicatorDescription } from "./MovingAverageConvergenceDivergenceIndicatorDescription";
/**
 * @hidden
 */
var MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata, _super);
    function MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.b = function (a) {
        if (MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.a == null) {
            MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.c(MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.a);
        }
        if (a.j(MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.y(MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.a);
    };
    MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.c = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.c(a);
        a.item("ShortPeriod", "Number:int");
        a.item("LongPeriod", "Number:int");
        a.item("SignalPeriod", "Number:int");
    };
    MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.d = function (a) {
        MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.b(a);
        a.aa("MovingAverageConvergenceDivergenceIndicator", function () { return new MovingAverageConvergenceDivergenceIndicatorDescription(); });
        a.z("MovingAverageConvergenceDivergenceIndicator", MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.a);
    };
    MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.$t = markType(MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata, 'MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata');
    MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.a = null;
    return MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata;
}(Base));
export { MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata };
